/*
 * LocateApplication.cpp
 *
 * Written by Matt Pauker
 *
 * Last modified: 11/9/96
 */
 
#include "LocateApplication.h"
#include "LocateWindow.h"

LocateApplication::LocateApplication() : BApplication('Lcte')
{
	// Create the window and show it
	myWindow = new LocateWindow();
	myWindow->Show();

	// Create the main menu
	BPopUpMenu *mainMenu;
	BMenuItem *menuItem;
	BMenu *menu;
	
	mainMenu = new BPopUpMenu("mainMenu");

	menuItem = new BMenuItem("About Locate", new BMessage(B_ABOUT_REQUESTED));
	mainMenu->AddItem(menuItem);
	mainMenu->AddSeparatorItem();
	
	// Font menu
	long numFonts, x;
	font_name fontName;
	
	menu = new BMenu("Font");
	menu->SetRadioMode(TRUE);
	numFonts = count_fonts();
	for (x = 0; x < numFonts; x++)
	{
		get_font_name(x, &fontName);
		menuItem = new BMenuItem(fontName, new BMessage(FONT_SELECTED));
		if (strcmp(fontName, "Erich") == 0)
			menuItem->SetMarked(TRUE);		// Erich is default font
		menu->AddItem(menuItem);
	}
	mainMenu->AddItem(menu);
	
	// Size menu
	menu = new BMenu("Size");
	menu->SetRadioMode(TRUE);
	menuItem = new BMenuItem("9", new BMessage(SIZE_SELECTED));
	menuItem->SetMarked(TRUE);		// 9pt. is default
	menu->AddItem(menuItem);
	menuItem = new BMenuItem("10", new BMessage(SIZE_SELECTED));
	menu->AddItem(menuItem);
	menuItem = new BMenuItem("12", new BMessage(SIZE_SELECTED));
	menu->AddItem(menuItem);
	menuItem = new BMenuItem("14", new BMessage(SIZE_SELECTED));
	menu->AddItem(menuItem);
	menuItem = new BMenuItem("18", new BMessage(SIZE_SELECTED));
	menu->AddItem(menuItem);
	menuItem = new BMenuItem("24", new BMessage(SIZE_SELECTED));
	menu->AddItem(menuItem);
	mainMenu->AddItem(menu);

	mainMenu->AddSeparatorItem();
	
	// Quit item
	menuItem = new BMenuItem("Quit", new BMessage(B_QUIT_REQUESTED), 'Q');
	mainMenu->AddItem(menuItem);
	
	SetMainMenu(mainMenu);
}

void LocateApplication::AboutRequested()
// Displays a simple about box
{
	BAlert *myAlert;
	
	myAlert = new BAlert("",
	"Locate - Version 1.0\n\nWritten by Matt Pauker\nNovember 9, 1996",
												"OK");
	myAlert->Go();
}

void LocateApplication::MessageReceived(BMessage *message)
{
	switch (message->what)
	{
		case FONT_SELECTED:
		// A font was selected from the main menu
		{
			const char *fontName;
			BView *containerView;
		
			// Get the font name	
			fontName = ((BMenuItem *)message->FindObject("source"))->Label();
		
			// Change the string view fonts
			myWindow->Lock();
			containerView = myWindow->FindView("containerView");
			containerView->FindView("xView")->SetFontName(fontName);
			containerView->FindView("yView")->SetFontName(fontName);
			myWindow->Unlock();
		
			// Resize the window	
			myWindow->ResizeWindow();
			
			break;
		}
		case SIZE_SELECTED:
		// A size was selected from the main menu
		{
			const char *fontSizeStr;
			long fontSize;
			BView *containerView;
		
			// Get the font size				
			fontSizeStr = ((BMenuItem *)message->FindObject("source"))->Label();
			fontSize = atol(fontSizeStr);
			
			// Change the string view sizes
			myWindow->Lock();
			containerView = myWindow->FindView("containerView");
			containerView->FindView("xView")->SetFontSize(fontSize);
			containerView->FindView("yView")->SetFontSize(fontSize);
			myWindow->Unlock();
		
			// Resize the window	
			myWindow->ResizeWindow();
			
			break;
		}

		default:
			BApplication::MessageReceived(message);
	}
}