/*
 * LocateWindow.cpp
 *
 * Written by Matt Pauker
 *
 * Last modified: 11/9/96
 */

#include "LocateWindow.h"
#include "LocateView.h"

LocateWindow::LocateWindow() :
	BWindow(BRect(100, 100, 200, 150), "Locate", B_TITLED_WINDOW, B_NOT_RESIZABLE|B_NOT_ZOOMABLE)
{
	// Create the container view
	LocateView *myView;
	
	myView = new LocateView(BRect(0, 0, 100, 150));
	AddChild(myView);
	
	// Resize the window
	ResizeWindow();

	// Set a faster pulse rate so the coordinates will be updated more often
	SetPulseRate(175000.0);
	
	// We can get some improved performance by turning off lock checking
	SetDiscipline(FALSE);
}

bool LocateWindow::QuitRequested()
{
	// We're the only window, so when we close, quit the app
	be_app->PostMessage(B_QUIT_REQUESTED);
	return TRUE;
}


void LocateWindow::ResizeWindow()
{
	LocateView *containerView;
	BStringView *xView, *yView;
	screen_info screenInfo;
	font_info fontInfo;
	char *s = new char[16];
	long height, width;
	
	Lock();
	containerView = (LocateView *)FindView("containerView");
	containerView->ResetCoords();		// Reset coords and force an update
	
	// Get the string views
	xView = (BStringView *)containerView->FindView("xView");
	yView = (BStringView *)containerView->FindView("yView");

	// Figure out how wide the window needs to be
	// Create a sample string with the max X coordinate and measure its width
	get_screen_info(&screenInfo);
	if (screenInfo.frame.right < 1000)
		sprintf(s, "X: %d", 999);
	else
		sprintf(s, "X: %d", 1999);
		
	width = (long)xView->StringWidth(s) + 8;
	
	// Figure out how tall the window needs to be
	// Get the height of the font
	xView->GetFontInfo(&fontInfo);
	height = 2 * (long)fontInfo.size + 13;
	
	xView->ResizeTo(width, (long)fontInfo.size + 3);
	yView->ResizeTo(width, (long)fontInfo.size + 3);
	yView->MoveTo(3, (long)fontInfo.size + 9);
		
	Unlock();
	
	ResizeTo(width, height);		// Resize the window

	delete[] s;
}	